@@ -1709,7 +1709,7 @@ asn1_der_decoding_startEnd(ASN1_TYPE element,const void *ider,int len,
 
   if(node==ASN1_TYPE_EMPTY) return ASN1_ELEMENT_NOT_FOUND;
 
-  node_to_find=_asn1_find_node(node,name_element);
+  node_to_find=asn1_find_node(node,name_element);
 
   if(node_to_find==NULL) return ASN1_ELEMENT_NOT_FOUND;
 
@@ -2170,7 +2170,7 @@ asn1_expand_octet_string(ASN1_TYPE definitions,ASN1_TYPE *element,
   if((definitions==ASN1_TYPE_EMPTY) || (*element==ASN1_TYPE_EMPTY))
     return ASN1_ELEMENT_NOT_FOUND;
 
-  octetNode=_asn1_find_node(*element,octetName);
+  octetNode=asn1_find_node(*element,octetName);
   if(octetNode==ASN1_TYPE_EMPTY)
     return ASN1_ELEMENT_NOT_FOUND;
   if(type_field(octetNode->type)!=TYPE_OCTET_STRING)
@@ -2178,7 +2178,7 @@ asn1_expand_octet_string(ASN1_TYPE definitions,ASN1_TYPE *element,
   if(octetNode->value==NULL)
     return ASN1_VALUE_NOT_FOUND;
 
-  objectNode=_asn1_find_node(*element,objectName);
+  objectNode=asn1_find_node(*element,objectName);
   if(objectNode==ASN1_TYPE_EMPTY)
     return ASN1_ELEMENT_NOT_FOUND;
 
