@@ -320,7 +320,7 @@ asn1_delete_element(ASN1_TYPE structure,const char *element_name)
 {
   node_asn *p2,*p3,*source_node;
 
-  source_node=_asn1_find_node(structure,element_name);
+  source_node=asn1_find_node(structure,element_name);
 
   if(source_node==ASN1_TYPE_EMPTY) return ASN1_ELEMENT_NOT_FOUND;
 
@@ -413,7 +413,7 @@ _asn1_copy_structure2(node_asn *root,const char *source_name)
 {
   node_asn *source_node;
 
-  source_node=_asn1_find_node(root,source_name);
+  source_node=asn1_find_node(root,source_name);
 
   return _asn1_copy_structure3(source_node);
 
@@ -623,7 +623,7 @@ asn1_print_structure(FILE *out,ASN1_TYPE structure,const char *name,int mode)
 
   if(out==NULL) return;
 
-  root=_asn1_find_node(structure,name);
+  root=asn1_find_node(structure,name);
 
   if(root==NULL) return;
 
@@ -900,7 +900,7 @@ asn1_number_of_elements(ASN1_TYPE element,const char *name,int *num)
 
   *num=0;
 
-  node=_asn1_find_node(element,name);
+  node=asn1_find_node(element,name);
   if(node==NULL) return ASN1_ELEMENT_NOT_FOUND;
 
   p=node->down;
@@ -967,3 +967,53 @@ asn1_find_structure_from_oid (ASN1_TYPE definitions,
 
   return NULL;  /* ASN1_ELEMENT_NOT_FOUND; */
 }
+
+/**
+ * asn1_copy_node:
+ * @dst: Destination ASN1_TYPE node.
+ * @dst_name: Field name in destination node.
+ * @src: Source ASN1_TYPE node.
+ * @src_name: Field name in source node.
+ *
+ * Create a deep copy of a ASN1_TYPE variable.
+ *
+ * Return value: Return ASN1_SUCCESS on success.
+ **/
+asn1_retCode
+asn1_copy_node (ASN1_TYPE dst, const char *dst_name,
+		ASN1_TYPE src, const char *src_name)
+{
+
+  int result;
+  ASN1_TYPE dst_node;
+  void *data = NULL;
+  int size = 0;
+
+  result = asn1_der_coding (src, src_name, NULL, &size, NULL);
+  if (result != ASN1_MEM_ERROR)
+    return result;
+
+  data = _asn1_malloc (size);
+  if (data == NULL)
+    return ASN1_MEM_ERROR;
+
+  result = asn1_der_coding (src, src_name, data, &size, NULL);
+  if (result != ASN1_SUCCESS)
+    {
+      _asn1_free (data);
+      return result;
+    }
+
+  dst_node = asn1_find_node (dst, dst_name);
+  if (dst_node == NULL)
+    {
+      _asn1_free (data);
+      return ASN1_ELEMENT_NOT_FOUND;
+    }
+
+  result = asn1_der_decoding (&dst_node, data, size, NULL);
+
+  _asn1_free (data);
+
+  return result;
+}
